==> webpdf-wsclient-2.0.3-sources.jar: net/webpdf/wsclient/schema/operation/QrSwissPaymentSeparatorType.java <==

package net.webpdf.wsclient.schema.operation;

import javax.xml.bind.annotation.XmlEnum;
import javax.xml.bind.annotation.XmlEnumValue;
import javax.xml.bind.annotation.XmlType;


/**
 * <p>Java class for QrSwissPaymentSeparatorType.
 * 
 * <p>The following schema fragment specifies the expected content contained within this class.
 * <p>
 * <pre>
 * &lt;simpleType name="QrSwissPaymentSeparatorType"&gt;
 *   &lt;restriction base="{http://www.w3.org/2001/XMLSchema}string"&gt;
 *     &lt;enumeration value="none"/&gt;
 *     &lt;enumeration value="solidLine"/&gt;
 *     &lt;enumeration value="solidLineWithScissors"/&gt;
 *     &lt;enumeration value="dashedLine"/&gt;
 *     &lt;enumeration value="dashedLineWithScissors"/&gt;
 *     &lt;enumeration value="dottedLine"/&gt;
 *     &lt;enumeration value="dottedLineWithScissors"/&gt;
 *   &lt;/restriction&gt;
 * &lt;/simpleType&gt;
 * </pre>
 * 
 */
@XmlType(name = "QrSwissPaymentSeparatorType")
@XmlEnum
public enum QrSwissPaymentSeparatorType {

    @XmlEnumValue("none")
    NONE("none"),
    @XmlEnumValue("solidLine")
    SOLID_LINE("solidLine"),
    @XmlEnumValue("solidLineWithScissors")
    SOLID_LINE_WITH_SCISSORS("solidLineWithScissors"),
    @XmlEnumValue("dashedLine")
    DASHED_LINE("dashedLine"),
    @XmlEnumValue("dashedLineWithScissors")
    DASHED_LINE_WITH_SCISSORS("dashedLineWithScissors"),
    @XmlEnumValue("dottedLine")
    DOTTED_LINE("dottedLine"),
    @XmlEnumValue("dottedLineWithScissors")
    DOTTED_LINE_WITH_SCISSORS("dottedLineWithScissors");
    private final String value;

    QrSwissPaymentSeparatorType(String v) {
        value = v;
    }

    public String value() {
        return value;
    }

    public static QrSwissPaymentSeparatorType fromValue(String v) {
        for (QrSwissPaymentSeparatorType c: QrSwissPaymentSeparatorType.values()) {
            if (c.value.equals(v)) {
                return c;
            }
        }
        throw new IllegalArgumentException(v);
    }

}

==> webpdf-wsclient-9.0.1-sources.jar: net/webpdf/wsclient/schema/operation/QrSwissPaymentSeparatorType.java <==

package net.webpdf.wsclient.schema.operation;

import jakarta.xml.bind.annotation.XmlEnum;
import jakarta.xml.bind.annotation.XmlEnumValue;
import jakarta.xml.bind.annotation.XmlType;


/**
 * <p>Java class for QrSwissPaymentSeparatorType.
 * 
 * <p>The following schema fragment specifies the expected content contained within this class.
 * <pre>{@code
 * <simpleType name="QrSwissPaymentSeparatorType">
 *   <restriction base="{http://www.w3.org/2001/XMLSchema}string">
 *     <enumeration value="none"/>
 *     <enumeration value="solidLine"/>
 *     <enumeration value="solidLineWithScissors"/>
 *     <enumeration value="dashedLine"/>
 *     <enumeration value="dashedLineWithScissors"/>
 *     <enumeration value="dottedLine"/>
 *     <enumeration value="dottedLineWithScissors"/>
 *   </restriction>
 * </simpleType>
 * }</pre>
 * 
 */
@XmlType(name = "QrSwissPaymentSeparatorType")
@XmlEnum
public enum QrSwissPaymentSeparatorType {

    @XmlEnumValue("none")
    NONE("none"),
    @XmlEnumValue("solidLine")
    SOLID_LINE("solidLine"),
    @XmlEnumValue("solidLineWithScissors")
    SOLID_LINE_WITH_SCISSORS("solidLineWithScissors"),
    @XmlEnumValue("dashedLine")
    DASHED_LINE("dashedLine"),
    @XmlEnumValue("dashedLineWithScissors")
    DASHED_LINE_WITH_SCISSORS("dashedLineWithScissors"),
    @XmlEnumValue("dottedLine")
    DOTTED_LINE("dottedLine"),
    @XmlEnumValue("dottedLineWithScissors")
    DOTTED_LINE_WITH_SCISSORS("dottedLineWithScissors");
    private final String value;

    QrSwissPaymentSeparatorType(String v) {
        value = v;
    }

    public String value() {
        return value;
    }

    public static QrSwissPaymentSeparatorType fromValue(String v) {
        for (QrSwissPaymentSeparatorType c: QrSwissPaymentSeparatorType.values()) {
            if (c.value.equals(v)) {
                return c;
            }
        }
        throw new IllegalArgumentException(v);
    }

}
